<?php
// $Id: contact_save.admin.inc,v 1.1 2010/03/22 18:38:25 joelstein Exp $

/**
 * Displays contact form submissions.
 */
function contact_save_submissions() {
  $sql = "SELECT cs.*, c.category AS category_category, u.name AS user_name
    FROM {contact_save} cs
    LEFT JOIN {contact} c ON cs.cid = c.cid
    LEFT JOIN {users} u ON cs.uid = u.uid";
  $limit = 20;
  $header = array(
    array('data' => t('Date'), 'field' => 'cs.created', 'sort' => 'desc'),
    array('data' => t('Name'), 'field' => 'cs.name'),
    array('data' => t('E-mail'), 'field' => 'cs.email'),
    array('data' => t('Subject'), 'field' => 'cs.subject'),
    array('data' => t('Category'), 'field' => 'cs.category'),
    array('data' => t('Replied'), 'field' => 'cs.replied'),
    array('data' => t('Actions'), 'colspan' => 2),
  );
  $tablesort = tablesort_sql($header);
  $result = pager_query($sql . $tablesort, $limit);
  
  $rows = array();
  while ($submission = db_fetch_object($result)) {
    $rows[] = array(
      _contact_save_format_field('created-date', $submission),
      _contact_save_format_field('name', $submission),
      _contact_save_format_field('email', $submission),
      _contact_save_format_field('subject', $submission),
      _contact_save_format_field('category', $submission),
      _contact_save_format_field('replied-date', $submission),
      l('view', 'admin/build/contact/submissions/' . $submission->id),
      l('delete', 'admin/build/contact/submissions/' . $submission->id . '/delete', array('query' => array('destination' => 'admin/build/contact/submissions'))),
    );
  }
  
  if (empty($rows)) {
    $rows[] = array(array('data' => t('No contact form submissions have been made yet.'), 'colspan' => 8));
  }
  
  $output = theme('table', $header, $rows);
  $output .= theme('pager', NULL, $limit, 0);
  return $output;
}

/**
 * View a contact form submissions.
 */
function contact_save_view_submission(&$form_state, $id) {
  drupal_add_css(drupal_get_path('module', 'contact_save') . '/contact_save.css');
  
  $submission = db_fetch_object(db_query("SELECT cs.*, c.category AS category_category, u.name AS user_name
    FROM {contact_save} cs
    LEFT JOIN {contact} c ON cs.cid = c.cid
    LEFT JOIN {users} u ON cs.uid = u.uid
    WHERE cs.id = %d", $id));
  
  // Show message details
  $output = '<dl class="contact-save-submissions">';
  $output .= "<dt>Date</dt><dd>" . _contact_save_format_field('created', $submission) . "</dd>";
  $output .= "<dt>Name</dt><dd>" . _contact_save_format_field('name', $submission) . "</dd>";
  $output .= "<dt>E-mail</dt><dd>" . _contact_save_format_field('email', $submission) . "</dd>";
  $output .= "<dt>Category</dt><dd>" . _contact_save_format_field('category', $submission) . "</dd>";
  $output .= "<dt>Recipients</dt><dd>" . _contact_save_format_field('recipients', $submission) . "</dd>";
  $output .= "<dt>Message</dt><dd>" . _contact_save_format_field('message', $submission) . "</dd>";
  if ($submission->reply) {
    $output .= "<dt>Replied</dt><dd>" . _contact_save_format_field('replied', $submission) . "</dd>";
    $output .= "<dt>Reply</dt><dd>" . _contact_save_format_field('reply', $submission) . "</dd>";
  }
  $output .= '</dl>';
  
  // Build the form, including the delete button
  $form['top'] = array('#value' => $output);
  $form['submission'] = array(
    '#type' => 'value',
    '#value' => $submission,
  );
  $form['delete'] = array(
    '#type' => 'submit',
    '#value' => t('Delete'),
    '#submit' => array('contact_save_delete_submit'),
  );
  
  // Only show reply form if no reply exists
  if (!$submission->reply) {
    $form['reply'] = array(
      '#type' => 'fieldset',
      '#title' => t('Reply to this message'),
      '#collapsible' => TRUE,
    );
    $form['reply']['subject'] = array(
      '#type' => 'textfield',
      '#title' => t('Subject'),
      '#default_value' => 'Re: [' . variable_get('site_name', 'Drupal') . '] ' . $submission->subject,
      '#required' => TRUE,
    );
    $args = array(
      '!name' => $submission->name,
      '!site_name' => variable_get('site_name', 'Drupal'),
    );
    $form['reply']['message'] = array(
      '#type' => 'textarea',
      '#title' => t('Message'),
      '#description' => t('This template can be modified on the ' . l('contact settings form', 'admin/build/contact/settings') . '. <em>Note</em>: The original message will be automatically included below your response.'),
      '#required' => TRUE,
      '#default_value' => t(variable_get('contact_save_reply_template', "Dear !name,\n\n\n\n-- !site_name team"), $args),
    );
    $form['reply']['submit'] = array(
      '#type' => 'submit',
      '#value' => 'Submit',
    );
  }
  
  return $form;
}

/**
 * View page submission callback; sends the reply.
 */
function contact_save_view_submission_submit($form, &$form_state) {
  $values = $form_state['values'];
  $submission = $values['submission'];
  
  // Send reply
  $to = $submission->email;
  $from = variable_get('site_mail', ini_get('sendmail_from'));
  drupal_mail('contact_save', 'reply', $to, language_default(), $values, $from);
  drupal_set_message(t('Your reply has been sent.'));
  
  // Save the reply
  $submission->reply = $values['message'];
  $submission->replied = time();
  drupal_write_record('contact_save', $submission, array('id'));
}

/**
 * Delete button submit function; redirects to confirmation page.
 */
function contact_save_delete_submit($form, &$form_state) {
  $form_state['redirect'] = 'admin/build/contact/submissions/' . $form_state['values']['submission']->id . '/delete';
}

/**
 * Delete confirmation page.
 */
function contact_save_delete_submission(&$form_state, $id) {
  $submission = db_fetch_object(db_query("SELECT cs.*, c.category AS category_category, u.name AS user_name
    FROM {contact_save} cs
    LEFT JOIN {contact} c ON cs.cid = c.cid
    LEFT JOIN {users} u ON cs.uid = u.uid
    WHERE cs.id = %d", $id));
  $form['submission'] = array(
    '#type' => 'value',
    '#value' => $submission,
  );
  $message = t('Are you sure you want to delete the contact form submission from %user created %date?', array(
    '%user' => strip_tags(_contact_save_format_field('name', $submission)),
    '%date' => _contact_save_format_field('created', $submission),
  ));
  $destination = isset($_GET['destination']) ? $_GET['destination'] : 'admin/build/contact/submissions/' . $submission->id;
  return confirm_form($form, $message, $destination, t('This action cannot be undone.'), t('Delete'), t('Cancel'));
}

/**
 * Delete form submission callback.
 */
function contact_save_delete_submission_submit($form, &$form_state) {
  $submission = $form_state['values']['submission'];
  db_query("DELETE FROM {contact_save} WHERE id = %d", $submission->id);
  drupal_set_message(t('%id has been deleted.', array('%id' => $submission->id)));
  $form_state['redirect'] = 'admin/build/contact/submissions';
  return;
}

/**
 * Implementation of hook_mail().
 */
function contact_save_mail($key, &$message, $params) {
  switch ($key) {
    case 'reply':
      $message['subject'] = $params['subject'];
      $message['body'][] = $params['message'];
      $message['body'][] = t('Your original message:');
      $message['body'][] = $params['submission']->message;
      break;
  }
}

/**
 * Formats submission fields.
 */
function _contact_save_format_field($field, $submission) {
  switch ($field) {
    case 'created-date':
      return format_date($submission->created, 'custom', 'Y-m-d');
    case 'created':
      return format_date($submission->created, 'custom', 'Y-m-d g:i a');
    case 'name':
      return $submission->user_name ? ((user_access('administer users') or user_access('access user profiles')) ? l($submission->user_name, 'user/' . $submission->uid) : $submission->user_name) : $submission->name;
    case 'email':
      return l($submission->email, 'mailto:' . $submission->email);
    case 'subject':
      return $submission->subject;
    case 'category':
      return $submission->category_category ? l($submission->category_category, 'admin/build/contact/edit/' . $submission->cid) : $submission->category;
    case 'recipients':
      return l($submission->recipients, 'mailto:' . $submission->recipients);
    case 'message':
      return nl2br($submission->message);
    case 'replied-date':
      return $submission->replied ? format_date($submission->replied, 'custom', 'Y-m-d') : '';
    case 'replied':
      return format_date($submission->replied, 'custom', 'Y-m-d g:i a');
    case 'reply':
      return nl2br($submission->reply);
  }
}
